@@ -282,7 +282,7 @@ def _check_irrad_ratio(ratio, ghi, sza, bounds):
     )
 
 
-def check_irradiance_consistency_qcrad(ghi, solar_zenith, dhi, dni,
+def check_irradiance_consistency_qcrad(solar_zenith, ghi, dhi, dni,
                                        param=None):
     """Check consistency of GHI, DHI and DNI using QCRad criteria.
 
@@ -295,10 +295,10 @@ def check_irradiance_consistency_qcrad(ghi, solar_zenith, dhi, dni,
 
     Parameters
     ----------
-    ghi : Series
-        Global horizontal irradiance in :math:`W/m^2`
     solar_zenith : Series
         Solar zenith angle in degrees
+    ghi : Series
+        Global horizontal irradiance in :math:`W/m^2`
     dhi : Series
         Diffuse horizontal irradiance in :math:`W/m^2`
     dni : Series
